@@ -4,12 +4,12 @@ use strict;
 use warnings;
 
 use parent qw(Exporter);
-our @EXPORT_OK = qw(prompt has_timed_out);
+our @EXPORT_OK = qw(prompt has_prompt_timed_out);
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
 use Carp ();
 
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 my $HAS_TIMED_OUT;
 my $DEFAULT_TIMEOUT_SEC = 60;
@@ -69,7 +69,7 @@ sub prompt {
     return $answer || $default_answer;
 }
 
-sub has_timed_out { $HAS_TIMED_OUT; }
+sub has_prompt_timed_out { $HAS_TIMED_OUT; }
 
 sub _parse_args {
     my %args = @_;
@@ -92,7 +92,7 @@ IO::Prompt::Timeout - Simple prompt interface with timeout.
 
     use IO::Prompt::Timeout qw(:all);
     my $answer = prompt('Yes or No? (y/n)', %option);
-    my $is_timeout = has_timed_out();
+    my $is_timeout = has_prompt_timed_out();
 
     # Specifying timeout seconds
     my $answer = prompt('Yes or No? (y/n) Answer in 10 seconds.', timeout => 10);
@@ -113,6 +113,17 @@ Unlike Prompt::Timeout, this module uses simple $SIG{ALRM}.
 The function of clearing timer by a single key click is not supported which is
 implemented in Prompt::Timeout.
 
+=head1 SUBROUTINES
+
+=head2 prompt : Answer(SCALAR)
+
+Show prompt and returns the answer by user's input.
+
+=head2 has_prompt_timed_out : BOOL
+
+Called after a I<prompt> call.
+Returns if I<prompt> subroutine has timed out or not.
+
 =head1 ENVIRONMENT VARIABLES
 
 =over 4
